import { HashMap } from '@ngneat/transloco';
import { TranslationMarkupRenderer } from './translation-markup-renderer.model';
import * as i0 from "@angular/core";
/**
 * Factory used for creating different types of `TranslationMarkupRenderer` instances.
 */
export declare class TranslationMarkupRendererFactory {
    /** Document instance used by the renderers to create the actual DOM nodes. */
    private readonly document;
    /**
     * Creates a new `TranslationMarkupRendererFactory` instance.
     *
     * @param document Document instance used by the renderers to create the actual DOM nodes.
     */
    constructor(document: any);
    /**
     * Creates a markup renderer to render text. This can be either a static text or on that dynamically resolved based on the translation
     * parameters.
     *
     * @param   text Text that is to be rendered or a function that returns the text to be rendered based on the translation parameters.
     * @returns      A `TranslationMarkupRenderer` that renders the specified text.
     */
    createTextRenderer(text: string | ((translationParameters: HashMap) => string)): TranslationMarkupRenderer;
    /**
     * Creates a markup renderer that renders an HTML element with the specified tag and (optionally) attaches the content rendered by the
     * given child markup renderers.
     *
     * @param   elementTag     Tag of the HTML element that is be created by the renderer.
     * @param   childRenderers An optional sequence of child markup renderers, which will be used to render the contents of the element.
     * @returns                A `TranslationMarkupRenderer` that renders the specified HTML element and optional content generated by the
     *                         given sequence of child renderers.
     */
    createElementRenderer<K extends keyof HTMLElementTagNameMap>(elementTag: K, childRenderers?: TranslationMarkupRenderer[]): TranslationMarkupRenderer<HTMLElementTagNameMap[K]>;
    createElementRenderer(elementTag: string, childRenderers?: TranslationMarkupRenderer[]): TranslationMarkupRenderer<HTMLElement>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TranslationMarkupRendererFactory, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TranslationMarkupRendererFactory>;
}
