import { LinkRenderer } from '../link-renderer.model';
import { ResolveLinkSpecification } from '../models/resolve-link-specification.model';
import { TranslationMarkupRendererFactory } from '../translation-markup-renderer-factory';
import { TranslationMarkupRenderer } from '../translation-markup-renderer.model';
import { BlockTranspiler } from './block-transpiler';
/**
 * Transpiler for named (special start and end token) link blocks. This can be used instead of the more generic `LinkTranspiler` to create
 * context specific link block transpilers.
 */
export declare class ContextualLinkBlockTranspiler extends BlockTranspiler {
    /** Object that specifies how to resolve the link. */
    private readonly resolveLinkSpecification;
    /** Renderer factory used to create the renderer for the HTML anchor element that will be substituted in place of the token. */
    private readonly rendererFactory;
    /** Set of link renderers that are used to apply the link model from the translation parameter to the anchor element. */
    private readonly linkRenderers;
    /**
     * Creates a new `NamedLinkBlockTranspiler` for the specified start and end token.
     */
    constructor(
    /** Token that defined the start of the link. */
    linkStartToken: string, 
    /** Token that defined the end of the link. */
    linkEndToken: string, 
    /** Object that specifies how to resolve the link. */
    resolveLinkSpecification: ResolveLinkSpecification, 
    /** Renderer factory used to create the renderer for the HTML anchor element that will be substituted in place of the token. */
    rendererFactory: TranslationMarkupRendererFactory, 
    /** Set of link renderers that are used to apply the link model from the translation parameter to the anchor element. */
    linkRenderers: LinkRenderer<unknown>[]);
    /** @inheritdoc */
    createRenderer(childRenderers: TranslationMarkupRenderer[]): TranslationMarkupRenderer;
}
